<?xml version="1.0" encoding="UTF-8"?>
<sch:schema xmlns:sch="http://www.ascc.net/xml/schematron">
  <!--	 
    VHitG schematron rules
    
    This file contains the Schematron validation rules for the Clinical Document Architecture (CDA) schema.

    See http://xml.ascc.net/resource/schematron/schematron.html for information about Schematron. 	 

    Author: Kai Heitmann <mailto:hl7@kheitmann.nl> 	 
    Rules: Global, Coding, Author, Diagnosis
    Template ID: CDA-R2-AB100-ruleset1
    Version: 1 Final
    Date: 2005-12-04 	 

-->
  <ns uri="urn:hl7-org:v3" prefix="cda"/>
  <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
  <title>CDA Schematron Rule Definitions CDA-R2-AB100-rule1</title>
  <!--
    Rules that pertain to multiple sections of the CDA
  -->
  <pattern name="1 Global Rules">
    <rule context="/">
      <assert test="cda:ClinicalDocument"> &lt;ClinicalDocument&gt; must be the root node with the namespace
        urn:hl7-org:v3. </assert>
    </rule>
  </pattern>
  <!--
    Rules that pertain to the coding of the CDA
  -->
  <pattern name="2 Coding Rules">
    <rule context="cda:recordTarget/cda:patientRole/cda:patient/cda:administrativeGenderCode">
      <assert test="(not(@nullFlavor) and @code='F' and @codeSystem='2.16.840.1.113883.5.1') or (not(@nullFlavor) and @code='M'
        and @codeSystem='2.16.840.1.113883.5.1') or (not(@nullFlavor) and @code='U' and
        @codeSystem='2.16.840.1.113883.5.1') or (@nullFlavor='UNK' and not(@code) and not(@codeSystem))"> If the gender is
        entered, the attributes code, and codeSystem are required attributes. The code must be either F, M or U, the codeSystem
        must be 2.16.840.1.113883.5.1. If the gender is not entered a NullFlavor attribute of UNK (only UNK, no other options
        allowed) must be entered. </assert>
    </rule>
  </pattern>
  <!--
    Rules that pertain to the Author section of the CDA
  -->
  <pattern name="3 Author">
    <rule context="cda:author/cda:assignedAuthor/cda:id">
      <assert test="(string-length(@extension)&gt;0) and (string-length(@root)&gt;0)"> The <name/> root and extension
        attributes must be not empty. </assert>
    </rule>
    <rule context="cda:ClinicalDocument">
      <assert test="count(cda:author/cda:assignedAuthor)=1"> There must be exactly one author/assignedAuthor. </assert>
    </rule>
  </pattern>
  <!--
   Rules that checks the presence of a assessment section with at least one diagnosis in the body of the CDA
  -->
  <pattern name="4 Diagnosis">
    <rule context="cda:ClinicalDocument/cda:component/cda:structuredBody">
      <assert test="count(cda:component/cda:section/cda:code[@code='27754-1' and @codeSystem='2.16.840.1.113883.6.1'])&gt;0">
        The CDA diagnosis section must be present at least once and be the following combination: &lt;code code="27754-1"
        codeSystem="2.16.840.1.113883.6.1"/&gt;</assert>
    </rule>
    <rule context="cda:component/cda:section/cda:code[@code='27754-1' and @codeSystem='2.16.840.1.113883.6.1']">
      <assert test="count(../cda:entry/cda:observation/cda:code[@codeSystem='2.16.840.1.113883.3.7.1.16' and @code='DISDX'])">
        Within the diagnosis section, there must be at leat one established diagnosis coded, using &lt;code code="DISDX"
        codeSystem="2.16.840.1.113883.3.7.1.16"/&gt;.</assert>
      <assert test="count(../cda:entry/cda:observation/cda:value[@codeSystem='1.2.276.0.76.5.311' and @code!=''])"> Within
        an established diagnosis, a value must be given using ICD10 gm 2006 codeSystem="1.2.276.0.76.5.311".</assert>
    </rule>
  </pattern>
</sch:schema>
